@@ -14,13 +14,12 @@ class PostMattermost:
 
 class Attachment:
 
-    def __init__(self, _fallback, _color, _text, _title, _title_link, _author_name, _fields):
+    def __init__(self, _fallback, _color, _text, _title, _title_link, _fields):
         self.fallback = _fallback
         self.color = _color
         self.text = _text
         self.title = _title
         self.title_link = _title_link
-        self.author_name = _author_name
         self.fields = _fields
 
 
@@ -47,35 +46,31 @@ def send_file_to_mattermost(url_webhook, ci_project_url, ci_job_id, title):
                             "Gitlab Artifact download link CI-JOB : " + ci_job_id,
                             title,
                             ci_project_url + "/-/jobs/" + str(ci_job_id) + "/artifacts/download?file_type=archive",
-                            None,
-                            [])
+                            None)
 
     push_post_mattermost(attachment, url_webhook)
 
 
-def send_rss_to_mattermost(url_webhook, title, title_link, publish_date, author, before_message, content):
+def send_rss_to_mattermost(url_webhook, title, title_link, users_mentioned, thread, content):
     """
 
     :param url_webhook:
     :param title:
     :param title_link:
-    :param publish_date:
-    :param author:
-    :param before_message:
+    :param users_mentioned:
+    :param thread:
     :param content:
     :return:
     """
 
-    field_publish_date = Field(False, "Publish date", publish_date)
-    field_author = Field(False, "Author", author)
+    field_users_mentioned = Field(False, users_mentioned, thread)
 
-    fields = [field_publish_date, field_author]
+    fields = [field_users_mentioned]
     attachment = Attachment("Gitlab RSS Feed",
                             "#FF8000",
                             content,
                             title,
                             title_link,
-                            before_message,
                             fields)
 
     push_post_mattermost(attachment, url_webhook)
